Learn R Programming

kosis (version 0.0.1)

castItem: Cast Item variable from the stat data downloaded from getStatData function

Description

Cast Item variable from the stat data downloaded from getStatData function

Usage

castItem(statData, itemVar = c("ITM_NM", "ITM_ID", "ITM_NM_ENG"))

Value

A data.frame object containing queried information

Arguments

statData

A data.frame downloaded from getStatData function

itemVar

A string specifying item variable

Details


## Example
statData <- getStatData(orgId = "101", tblId = "DT_1B41", objL1 = "ALL")
castItem(statData = statData, itemVar = "ITM_NM")